# Security Policy

## Supported Versions

The following chart shows versions of `django-helpdesk` that are currently receiving bugfixes and security patches.

| Version | Support History    | Last Date of Support             |
| ------- | ------------------ | -------------------------------- |
| 0.3.x   | :white_check_mark: | will be set after release of 0.4 |
| 0.2.x   | :white_check_mark: | 2021-12-31                       |
| < 0.2   | :x:                | 2016-10-31

## Reporting a Vulnerability

If you believe you have discovered a bug impacting security in a supported version, please DO NOT file a Issue / Bug Report for it publicly.

Instead, please send details to <garret@wassiverse.com>. Please be sure to include "django-helpdesk security issue" in the subject line for fastest response.

Once reported, we'll be in touch to confirm the issue and work toward releasing a patch as soon as possible.

After a patch has been released, a new release will be tagged and uploaded to PyPi, etc. At that time, details of the issue will be announced publicly.

Users are always highly encouraged to upgrade to the latest bugfix release as soon as possible.
